@@ -1,4 +1,19 @@
-def print_menu(options: list, sep=None, title='Menu', input_text='Select an option: ') -> str:
+
+def ask_option(options_lenght: int, input_text='Select an option: ') -> int:
+    try:
+        choice = input(f'{input_text}')
+        while True:
+            if choice.isdigit():
+                choice = int(choice)
+                if choice in range(1, options_lenght + 2):
+                    return choice
+            choice = input('Select a valid option: ')
+    except KeyboardInterrupt:
+        print()
+        return options_lenght + 1
+
+
+def print_menu(options: list, sep=None, title='Menu'):
     """
     Parameters
     ----------
@@ -18,14 +33,3 @@ def print_menu(options: list, sep=None, title='Menu', input_text='Select an opti
     for indx, o in enumerate(options):
         print(f'[{indx + 1}] {o}')
     print(f'[{len(options)+1}] Exit')
-    try:
-        choice = input(f'{input_text}')
-        while True:
-            if choice.isdigit():
-                choice = int(choice)
-                if choice in range(1, len(options) + 2):
-                    return choice
-            choice = input('Select a valid option: ')
-    except KeyboardInterrupt:
-        print()
-        return len(options) + 1
